You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by el...@apache.org on 2011/11/12 19:24:43 UTC

svn commit: r1201297 [1/9] - in /directory/apacheds/branches/apacheds-txns: all/ apache-felix/ core-annotations/ core-api/ core-api/src/main/java/org/apache/directory/server/core/api/ core-api/src/main/java/org/apache/directory/server/core/api/intercep...

Author: elecharny
Date: Sat Nov 12 18:24:38 2011
New Revision: 1201297

URL: http://svn.apache.org/viewvc?rev=1201297&view=rev
Log:
Merged back trunk into the TXN branch

Added:
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/InterceptorEnum.java
      - copied unchanged from r1201283, directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/api/InterceptorEnum.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/GetRootDseOperationContext.java
      - copied unchanged from r1201283, directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/GetRootDseOperationContext.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/HasEntryOperationContext.java
      - copied unchanged from r1201283, directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/HasEntryOperationContext.java
Removed:
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/InterceptorChain.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/NextInterceptor.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/EntryOperationContext.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/GetRootDSEOperationContext.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/invocation/
    directory/apacheds/branches/apacheds-txns/core/src/test/java/org/apache/directory/server/core/interceptor/
Modified:
    directory/apacheds/branches/apacheds-txns/all/   (props changed)
    directory/apacheds/branches/apacheds-txns/apache-felix/   (props changed)
    directory/apacheds/branches/apacheds-txns/core/   (props changed)
    directory/apacheds/branches/apacheds-txns/core-annotations/   (props changed)
    directory/apacheds/branches/apacheds-txns/core-annotations/pom.xml
    directory/apacheds/branches/apacheds-txns/core-api/   (props changed)
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/DirectoryService.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/LdapCoreSessionConnection.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/OperationEnum.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/OperationManager.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/BaseInterceptor.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/Interceptor.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/AbstractOperationContext.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/AddOperationContext.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/ModifyOperationContext.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/MoveAndRenameOperationContext.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/MoveOperationContext.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/RenameOperationContext.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/SearchOperationContext.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/partition/Partition.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/partition/PartitionNexus.java
    directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/schema/SchemaPartition.java
    directory/apacheds/branches/apacheds-txns/core-api/src/test/java/org/apache/directory/server/core/api/MockCoreSession.java
    directory/apacheds/branches/apacheds-txns/core-api/src/test/java/org/apache/directory/server/core/api/MockDirectoryService.java
    directory/apacheds/branches/apacheds-txns/core-api/src/test/java/org/apache/directory/server/core/api/MockInterceptor.java
    directory/apacheds/branches/apacheds-txns/core-api/src/test/java/org/apache/directory/server/core/api/MockOperation.java
    directory/apacheds/branches/apacheds-txns/core-api/src/test/java/org/apache/directory/server/core/api/MockOperationManager.java
    directory/apacheds/branches/apacheds-txns/core-avl/   (props changed)
    directory/apacheds/branches/apacheds-txns/core-constants/   (props changed)
    directory/apacheds/branches/apacheds-txns/core-integ/   (props changed)
    directory/apacheds/branches/apacheds-txns/core-integ/src/test/java/org/apache/directory/server/core/authn/ppolicy/PasswordPolicyTest.java
    directory/apacheds/branches/apacheds-txns/core-integ/src/test/java/org/apache/directory/server/core/authz/AuthzAuthnIT.java
    directory/apacheds/branches/apacheds-txns/core-integ/src/test/java/org/apache/directory/server/core/authz/support/MaxImmSubFilterTest.java
    directory/apacheds/branches/apacheds-txns/core-integ/src/test/java/org/apache/directory/server/core/collective/CollectiveAttributeServiceIT.java   (props changed)
    directory/apacheds/branches/apacheds-txns/core-integ/src/test/java/org/apache/directory/server/core/operations/getRootDse/GetRootDsePerfIT.java
    directory/apacheds/branches/apacheds-txns/core-integ/src/test/java/org/apache/directory/server/core/operations/hasEntry/hasEntryPerfIT.java
    directory/apacheds/branches/apacheds-txns/core-integ/src/test/java/org/apache/directory/server/core/partition/PartitionIT.java
    directory/apacheds/branches/apacheds-txns/core-integ/src/test/java/org/apache/directory/server/core/schema/PartitionSchemaLoaderTest.java   (props changed)
    directory/apacheds/branches/apacheds-txns/core-integ/src/test/java/org/apache/directory/server/core/schema/SubschemaSubentryIT.java
    directory/apacheds/branches/apacheds-txns/core-jndi/   (props changed)
    directory/apacheds/branches/apacheds-txns/core-jndi/src/main/java/org/apache/directory/server/core/jndi/ServerContext.java
    directory/apacheds/branches/apacheds-txns/core-jndi/src/main/java/org/apache/directory/server/core/jndi/ServerDirContext.java
    directory/apacheds/branches/apacheds-txns/core-shared/   (props changed)
    directory/apacheds/branches/apacheds-txns/core-shared/src/main/java/org/apache/directory/server/core/shared/DefaultCoreSession.java
    directory/apacheds/branches/apacheds-txns/core-shared/src/main/java/org/apache/directory/server/core/shared/partition/DefaultPartitionNexus.java
    directory/apacheds/branches/apacheds-txns/core/src/main/java/org/apache/directory/server/core/DefaultDirectoryService.java
    directory/apacheds/branches/apacheds-txns/core/src/main/java/org/apache/directory/server/core/DefaultOperationManager.java
    directory/apacheds/branches/apacheds-txns/dependencies/   (props changed)
    directory/apacheds/branches/apacheds-txns/http-directory-bridge/   (props changed)
    directory/apacheds/branches/apacheds-txns/http-integration/   (props changed)
    directory/apacheds/branches/apacheds-txns/i18n/   (props changed)
    directory/apacheds/branches/apacheds-txns/installers/   (props changed)
    directory/apacheds/branches/apacheds-txns/installers-maven-plugin/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptor-kerberos/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptor-kerberos/src/main/java/org/apache/directory/server/core/kerberos/KeyDerivationInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/admin/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/admin/src/main/java/org/apache/directory/server/core/admin/AdministrativePointInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/authn/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/authn/src/main/java/org/apache/directory/server/core/authn/AbstractAuthenticator.java
    directory/apacheds/branches/apacheds-txns/interceptors/authn/src/main/java/org/apache/directory/server/core/authn/AuthenticationInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/authz/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/authz/src/main/java/org/apache/directory/server/core/authz/AciAuthorizationInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/authz/src/main/java/org/apache/directory/server/core/authz/DefaultAuthorizationInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/authz/src/main/java/org/apache/directory/server/core/authz/support/MaxImmSubFilter.java
    directory/apacheds/branches/apacheds-txns/interceptors/changelog/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/changelog/src/main/java/org/apache/directory/server/core/changelog/ChangeLogInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/collective/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/collective/src/main/java/org/apache/directory/server/core/collective/CollectiveAttributeInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/event/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/event/src/main/java/org/apache/directory/server/core/event/EventInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/exception/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/exception/src/main/java/org/apache/directory/server/core/exception/ExceptionInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/hash/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/hash/src/main/java/org/apache/directory/server/core/hash/CryptPasswordHashingInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/hash/src/main/java/org/apache/directory/server/core/hash/Md5PasswordHashingInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/hash/src/main/java/org/apache/directory/server/core/hash/PasswordHashingInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/hash/src/main/java/org/apache/directory/server/core/hash/Sha256PasswordHashingInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/hash/src/main/java/org/apache/directory/server/core/hash/Sha384PasswordHashingInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/hash/src/main/java/org/apache/directory/server/core/hash/Sha512PasswordHashingInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/hash/src/main/java/org/apache/directory/server/core/hash/ShaPasswordHashingInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/hash/src/main/java/org/apache/directory/server/core/hash/Smd5PasswordHashingInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/hash/src/main/java/org/apache/directory/server/core/hash/Ssha256PasswordHashingInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/hash/src/main/java/org/apache/directory/server/core/hash/Ssha384PasswordHashingInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/hash/src/main/java/org/apache/directory/server/core/hash/Ssha512PasswordHashingInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/hash/src/main/java/org/apache/directory/server/core/hash/SshaPasswordHashingInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/journal/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/journal/src/main/java/org/apache/directory/server/core/journal/JournalInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/logger/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/logger/src/main/java/org/apache/directory/server/core/logger/TimerInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/normalization/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/normalization/src/main/java/org/apache/directory/server/core/normalization/NormalizationInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/operational/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/operational/src/main/java/org/apache/directory/server/core/operational/OperationalAttributeInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/referral/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/referral/src/main/java/org/apache/directory/server/core/referral/ReferralInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/schema/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/schema/src/main/java/org/apache/directory/server/core/schema/SchemaInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/schema/src/main/java/org/apache/directory/server/core/schema/SchemaLdifToPartitionExtractor.java
    directory/apacheds/branches/apacheds-txns/interceptors/schema/src/main/java/org/apache/directory/server/core/schema/SchemaSubentryModifier.java
    directory/apacheds/branches/apacheds-txns/interceptors/subtree/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/subtree/src/main/java/org/apache/directory/server/core/subtree/SubentryInterceptor.java
    directory/apacheds/branches/apacheds-txns/interceptors/trigger/   (props changed)
    directory/apacheds/branches/apacheds-txns/interceptors/trigger/src/main/java/org/apache/directory/server/core/trigger/TriggerInterceptor.java
    directory/apacheds/branches/apacheds-txns/jdbm/   (props changed)
    directory/apacheds/branches/apacheds-txns/jdbm-partition/   (props changed)
    directory/apacheds/branches/apacheds-txns/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/tree/   (props changed)
    directory/apacheds/branches/apacheds-txns/jdbm-partition/src/test/java/org/apache/directory/server/core/partition/tree/PartitionTreeTest.java   (props changed)
    directory/apacheds/branches/apacheds-txns/kerberos-codec/   (props changed)
    directory/apacheds/branches/apacheds-txns/kerberos-codec/src/main/java/org/apache/directory/server/   (props changed)
    directory/apacheds/branches/apacheds-txns/kerberos-codec/src/main/java/org/apache/directory/server/kerberos/protocol/codec/KerberosProtocolCodecFactory.java   (props changed)
    directory/apacheds/branches/apacheds-txns/kerberos-codec/src/main/java/org/apache/directory/shared/kerberos/codec/types/PaDataType.java   (props changed)
    directory/apacheds/branches/apacheds-txns/kerberos-codec/src/main/java/org/apache/directory/shared/kerberos/codec/types/SamType.java   (props changed)
    directory/apacheds/branches/apacheds-txns/kerberos-codec/src/main/java/org/apache/directory/shared/kerberos/components/Checksum.java   (props changed)
    directory/apacheds/branches/apacheds-txns/kerberos-codec/src/main/java/org/apache/directory/shared/kerberos/components/EncryptionKey.java   (props changed)
    directory/apacheds/branches/apacheds-txns/kerberos-codec/src/main/java/org/apache/directory/shared/kerberos/components/KdcReqBody.java
    directory/apacheds/branches/apacheds-txns/kerberos-codec/src/main/java/org/apache/directory/shared/kerberos/components/PaData.java   (props changed)
    directory/apacheds/branches/apacheds-txns/kerberos-codec/src/main/java/org/apache/directory/shared/kerberos/crypto/checksum/ChecksumType.java   (props changed)
    directory/apacheds/branches/apacheds-txns/kerberos-codec/src/main/java/org/apache/directory/shared/kerberos/flags/   (props changed)
    directory/apacheds/branches/apacheds-txns/kerberos-codec/src/main/java/org/apache/directory/shared/kerberos/messages/ApReq.java
    directory/apacheds/branches/apacheds-txns/kerberos-codec/src/main/java/org/apache/directory/shared/kerberos/messages/Authenticator.java
    directory/apacheds/branches/apacheds-txns/kerberos-codec/src/main/java/org/apache/directory/shared/kerberos/messages/KrbError.java   (props changed)
    directory/apacheds/branches/apacheds-txns/kerberos-codec/src/main/java/org/apache/directory/shared/kerberos/messages/TgsReq.java
    directory/apacheds/branches/apacheds-txns/kerberos-codec/src/test/java/org/apache/directory/server/   (props changed)
    directory/apacheds/branches/apacheds-txns/kerberos-test/   (props changed)
    directory/apacheds/branches/apacheds-txns/kerberos-test/src/test/java/org/apache/directory/server/kerberos/kdc/AbstractKerberosITest.java
    directory/apacheds/branches/apacheds-txns/kerberos-test/src/test/java/org/apache/directory/server/kerberos/kdc/SaslGssapiBindITest.java
    directory/apacheds/branches/apacheds-txns/ldap-client-test/   (props changed)
    directory/apacheds/branches/apacheds-txns/ldif-partition/   (props changed)
    directory/apacheds/branches/apacheds-txns/protocol-dhcp/   (props changed)
    directory/apacheds/branches/apacheds-txns/protocol-dns/   (props changed)
    directory/apacheds/branches/apacheds-txns/protocol-kerberos/   (props changed)
    directory/apacheds/branches/apacheds-txns/protocol-ldap/   (props changed)
    directory/apacheds/branches/apacheds-txns/protocol-ldap/src/main/java/org/apache/directory/server/ldap/handlers/SearchHandler.java
    directory/apacheds/branches/apacheds-txns/protocol-ldap/src/main/java/org/apache/directory/server/ldap/replication/consumer/ReplicationConsumerImpl.java   (props changed)
    directory/apacheds/branches/apacheds-txns/protocol-ntp/   (props changed)
    directory/apacheds/branches/apacheds-txns/protocol-shared/   (props changed)
    directory/apacheds/branches/apacheds-txns/server-annotations/   (props changed)
    directory/apacheds/branches/apacheds-txns/server-config/   (props changed)
    directory/apacheds/branches/apacheds-txns/server-config/src/main/java/org/apache/directory/server/config/ConfigPartitionReader.java   (props changed)
    directory/apacheds/branches/apacheds-txns/server-config/src/main/resources/   (props changed)
    directory/apacheds/branches/apacheds-txns/server-config/src/test/java/org/apache/directory/server/config/ConfigPartitionReaderTest.java   (props changed)
    directory/apacheds/branches/apacheds-txns/server-integ/   (props changed)
    directory/apacheds/branches/apacheds-txns/server-integ/pom.xml
    directory/apacheds/branches/apacheds-txns/server-integ/src/test/java/org/apache/directory/server/operations/bind/MiscBindIT.java
    directory/apacheds/branches/apacheds-txns/server-integ/src/test/java/org/apache/directory/server/operations/bind/SimpleBindIT.java
    directory/apacheds/branches/apacheds-txns/server-integ/src/test/java/org/apache/directory/server/operations/search/SearchLimitsIT.java
    directory/apacheds/branches/apacheds-txns/server-jndi/   (props changed)
    directory/apacheds/branches/apacheds-txns/server-replication/   (props changed)
    directory/apacheds/branches/apacheds-txns/service/   (props changed)
    directory/apacheds/branches/apacheds-txns/service-builder/   (props changed)
    directory/apacheds/branches/apacheds-txns/service-builder/src/main/java/org/apache/directory/server/config/builder/ServiceBuilder.java
    directory/apacheds/branches/apacheds-txns/service-osgi/   (props changed)
    directory/apacheds/branches/apacheds-txns/service/pom.xml
    directory/apacheds/branches/apacheds-txns/test-framework/   (props changed)
    directory/apacheds/branches/apacheds-txns/test-framework/pom.xml
    directory/apacheds/branches/apacheds-txns/wrapper/   (props changed)
    directory/apacheds/branches/apacheds-txns/xdbm-partition/   (props changed)
    directory/apacheds/branches/apacheds-txns/xdbm-partition/pom.xml
    directory/apacheds/branches/apacheds-txns/xdbm-partition/src/main/java/org/apache/directory/server/core/partition/impl/btree/AbstractBTreePartition.java
    directory/apacheds/branches/apacheds-txns/xdbm-tools/   (props changed)

Propchange: directory/apacheds/branches/apacheds-txns/all/
------------------------------------------------------------------------------
--- svn:mergeinfo (original)
+++ svn:mergeinfo Sat Nov 12 18:24:38 2011
@@ -3,6 +3,6 @@
 /directory/apacheds/branches/apacheds-dnfactory-experiment/all:980138-980938
 /directory/apacheds/branches/apacheds-kerberos-codec-2.0/all:1040956-1043765
 /directory/apacheds/branches/milestones/all:1072812-1075328
-/directory/apacheds/trunk/all:1066126-1067785,1068026-1072718,1072800-1075329,1177661-1186968
+/directory/apacheds/trunk/all:1066126-1067785,1068026-1072718,1072800-1075329,1177661-1201283
 /directory/apacheds/trunk/interceptors/all:1183435-1186974
 /directory/studio/trunk/all:1067786-1067997

Propchange: directory/apacheds/branches/apacheds-txns/apache-felix/
------------------------------------------------------------------------------
--- svn:mergeinfo (added)
+++ svn:mergeinfo Sat Nov 12 18:24:38 2011
@@ -0,0 +1,10 @@
+/directory/apacheds/branches/apacheds-codec-merge/apache-felix:982369-987590
+/directory/apacheds/branches/apacheds-config/apache-felix:1023442-1029077
+/directory/apacheds/branches/apacheds-kerberos-codec-2.0/apache-felix:1040956-1043765
+/directory/apacheds/branches/apacheds-replication/apache-felix:749790-764110
+/directory/apacheds/branches/apacheds-schema/apache-felix:806623-896441
+/directory/apacheds/branches/apacheds-subtree/apache-felix:965203-965686
+/directory/apacheds/branches/milestones/apache-felix:1072812-1075328
+/directory/apacheds/branches/xdbm-refactoring/apache-felix:945827-946347
+/directory/apacheds/trunk/apache-felix:1066126-1067785,1068026-1072718,1072800-1075329,1185228-1201283
+/directory/studio/trunk/apache-felix:1067786-1067997

Propchange: directory/apacheds/branches/apacheds-txns/core/
------------------------------------------------------------------------------
--- svn:mergeinfo (original)
+++ svn:mergeinfo Sat Nov 12 18:24:38 2011
@@ -5,6 +5,6 @@
 /directory/apacheds/branches/apacheds-jdbm/core:1160768-1164072
 /directory/apacheds/branches/apacheds-kerberos-codec-2.0/core:1040956-1043765
 /directory/apacheds/branches/milestones/core:1072812-1075328
-/directory/apacheds/trunk/core:1066126-1067785,1068026-1072718,1072800-1075329,1177661-1200383
+/directory/apacheds/trunk/core:1066126-1067785,1068026-1072718,1072800-1075329,1177661-1201283
 /directory/apacheds/trunk/interceptors/core:1183435-1186974
 /directory/studio/trunk/core:1067786-1067997

Propchange: directory/apacheds/branches/apacheds-txns/core-annotations/
------------------------------------------------------------------------------
--- svn:mergeinfo (original)
+++ svn:mergeinfo Sat Nov 12 18:24:38 2011
@@ -5,6 +5,6 @@
 /directory/apacheds/branches/apacheds-jdbm/core-annotations:1160768-1164073
 /directory/apacheds/branches/apacheds-kerberos-codec-2.0/core-annotations:1040956-1043765
 /directory/apacheds/branches/milestones/core-annotations:1072812-1075328
-/directory/apacheds/trunk/core-annotations:1066126-1067785,1068026-1072718,1072800-1075329,1177661-1186967
+/directory/apacheds/trunk/core-annotations:1066126-1067785,1068026-1072718,1072800-1075329,1177661-1201283
 /directory/apacheds/trunk/interceptors/core-annotations:1183435-1186974
 /directory/studio/trunk/core-annotations:1067786-1067997

Modified: directory/apacheds/branches/apacheds-txns/core-annotations/pom.xml
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/apacheds-txns/core-annotations/pom.xml?rev=1201297&r1=1201296&r2=1201297&view=diff
==============================================================================
--- directory/apacheds/branches/apacheds-txns/core-annotations/pom.xml (original)
+++ directory/apacheds/branches/apacheds-txns/core-annotations/pom.xml Sat Nov 12 18:24:38 2011
@@ -80,6 +80,12 @@
     
     <dependency>
       <groupId>org.apache.directory.shared</groupId>
+      <artifactId>shared-ldap-codec-standalone</artifactId>
+      <scope>test</scope>
+    </dependency>
+    
+    <dependency>
+      <groupId>org.apache.directory.shared</groupId>
       <artifactId>shared-ldap-model</artifactId>
     </dependency>
     

Propchange: directory/apacheds/branches/apacheds-txns/core-api/
------------------------------------------------------------------------------
--- svn:mergeinfo (original)
+++ svn:mergeinfo Sat Nov 12 18:24:38 2011
@@ -5,6 +5,6 @@
 /directory/apacheds/branches/apacheds-kerberos-codec-2.0/core-api:1040956-1043765
 /directory/apacheds/branches/apacheds-osgi/core-api:1185681-1199319
 /directory/apacheds/branches/milestones/core-api:1072812-1075328
-/directory/apacheds/trunk/core-api:1066126-1067785,1068026-1072718,1072800-1075329,1177661-1200380
+/directory/apacheds/trunk/core-api:1066126-1067785,1068026-1072718,1072800-1075329,1177661-1201283
 /directory/apacheds/trunk/interceptors/core-api:1183435-1186974
 /directory/studio/trunk/core-api:1067786-1067997

Modified: directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/DirectoryService.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/DirectoryService.java?rev=1201297&r1=1201296&r2=1201297&view=diff
==============================================================================
--- directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/DirectoryService.java (original)
+++ directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/DirectoryService.java Sat Nov 12 18:24:38 2011
@@ -6,16 +6,16 @@
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
- *  
+ * 
  *    http://www.apache.org/licenses/LICENSE-2.0
- *  
+ * 
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
  *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  *  KIND, either express or implied.  See the License for the
  *  specific language governing permissions and limitations
- *  under the License. 
- *  
+ *  under the License.
+ * 
  */
 package org.apache.directory.server.core.api;
 
@@ -32,7 +32,6 @@ import org.apache.directory.server.core.
 import org.apache.directory.server.core.api.entry.ServerEntryFactory;
 import org.apache.directory.server.core.api.event.EventService;
 import org.apache.directory.server.core.api.interceptor.Interceptor;
-import org.apache.directory.server.core.api.interceptor.InterceptorChain;
 import org.apache.directory.server.core.api.journal.Journal;
 import org.apache.directory.server.core.api.partition.Partition;
 import org.apache.directory.server.core.api.partition.PartitionNexus;
@@ -97,11 +96,8 @@ public interface DirectoryService extend
     PartitionNexus getPartitionNexus();
 
 
-    InterceptorChain getInterceptorChain();
-
-
     void addPartition( Partition partition ) throws Exception;
-    
+
 
     void removePartition( Partition partition ) throws Exception;
 
@@ -109,20 +105,20 @@ public interface DirectoryService extend
      * @return The Directory Service SchemaManager
      */
     SchemaManager getSchemaManager();
-    
-    
+
+
     /**
      * @return The LDAP codec service.
      */
     LdapApiService getLdapCodecService();
-    
+
 
     /**
      * @return The referral manager
      */
     ReferralManager getReferralManager();
 
-    
+
     /**
      * Set the referralManager
      * 
@@ -130,7 +126,7 @@ public interface DirectoryService extend
      */
     void setReferralManager( ReferralManager referralManager );
 
-    
+
     /**
      * @return The schema partition
      */
@@ -145,8 +141,8 @@ public interface DirectoryService extend
 
 
     EventService getEventService();
-    
-    
+
+
     /**
      */
     void setEventService( EventService eventService );
@@ -181,15 +177,15 @@ public interface DirectoryService extend
      */
     boolean isStarted();
 
-    
+
     /**
      * @return The Admin session
      */
     CoreSession getAdminSession();
-    
-    
-    /** 
-     * @return Returns the hash mapping the Dn of a subentry to its SubtreeSpecification/types 
+
+
+    /**
+     * @return Returns the hash mapping the Dn of a subentry to its SubtreeSpecification/types
      **/
     SubentryCache getSubentryCache();
 
@@ -197,42 +193,42 @@ public interface DirectoryService extend
      * @return Returns the subentry evaluator
      */
     SubtreeEvaluator getEvaluator();
-    
+
     /**
      * Gets a logical session to perform operations on this DirectoryService
-     * as the anonymous user.  This bypasses authentication without 
+     * as the anonymous user.  This bypasses authentication without
      * propagating a bind operation into the core.
      *
      * @return a logical session as the anonymous user
      */
     CoreSession getSession() throws Exception;
 
-    
+
     /**
      * Gets a logical session to perform operations on this DirectoryService
-     * as a specific user.  This bypasses authentication without propagating 
+     * as a specific user.  This bypasses authentication without propagating
      * a bind operation into the core.
      *
      * @return a logical session as a specific user
      */
     CoreSession getSession( LdapPrincipal principal ) throws Exception;
 
-    
+
     /**
      * Gets a logical session to perform operations on this DirectoryService
-     * as a specific user with a separate authorization principal.  This 
-     * bypasses authentication without propagating a bind operation into the 
+     * as a specific user with a separate authorization principal.  This
+     * bypasses authentication without propagating a bind operation into the
      * core.
      *
      * @return a logical session as a specific user
      */
     CoreSession getSession( Dn principalDn, byte[] credentials ) throws LdapException;
 
-    
+
     /**
      * Gets a logical session to perform operations on this DirectoryService
-     * as a specific user with a separate authorization principal.  This 
-     * bypasses authentication without propagating a bind operation into the 
+     * as a specific user with a separate authorization principal.  This
+     * bypasses authentication without propagating a bind operation into the
      * core.
      *
      * @return a logical session as a specific user
@@ -240,7 +236,7 @@ public interface DirectoryService extend
     CoreSession getSession( Dn principalDn, byte[] credentials, String saslMechanism, String saslAuthId )
         throws Exception;
 
-    
+
     /**
      */
     void setInstanceId( String instanceId );
@@ -341,29 +337,29 @@ public interface DirectoryService extend
      * @param interceptors the interceptors to be used in the server.
      */
     void setInterceptors( List<Interceptor> interceptors );
-    
-    
+
+
     /**
      * Add an interceptor in the first position in the interceptor list.
      * @param interceptor The added interceptor
      */
     void addFirst( Interceptor interceptor ) throws LdapException;
-    
-    
+
+
     /**
      * Add an interceptor in the last position in the interceptor list.
      * @param interceptor The added interceptor
      */
     void addLast( Interceptor interceptor ) throws LdapException;
-    
+
     /**
      * Add an interceptor after a given interceptor in the interceptor list.
      * @param interceptorName The interceptor name to find
      * @param interceptor The added interceptor
      */
     void addAfter( String interceptorName, Interceptor interceptor );
-    
-    
+
+
     /**
      * Remove an interceptor from the list of interceptors
      * @param interceptorName The interceptor to remove
@@ -378,7 +374,7 @@ public interface DirectoryService extend
      */
     void setJournal( Journal journal );
 
-    
+
     /**
      * Returns test directory entries({@link org.apache.directory.shared.ldap.model.ldif.LdifEntry}) to be loaded while
      * bootstrapping.
@@ -404,7 +400,7 @@ public interface DirectoryService extend
      */
     InstanceLayout getInstanceLayout();
 
-    
+
     /**
      * Sets the InstanceLayout used by the DirectoryService to store the files
      * @param instanceLayout The InstanceLayout to set
@@ -477,7 +473,7 @@ public interface DirectoryService extend
      * @param changeLog the change log service to set
      */
     void setChangeLog( ChangeLog changeLog );
-    
+
 
     /**
      * Create a new Entry.
@@ -486,8 +482,8 @@ public interface DirectoryService extend
      * @param dn the Dn for this new entry
      */
     Entry newEntry( String ldif, String dn );
-    
-    
+
+
     /**
      * Gets the operation manager.
      */
@@ -501,21 +497,21 @@ public interface DirectoryService extend
 
 
     /**
-     * Set the maximum allowed size for an incoming PDU 
+     * Set the maximum allowed size for an incoming PDU
      * @param maxPDUSize A positive number of bytes for the PDU. A negative or
      * null value will be transformed to {@link Integer#MAX_VALUE}
      */
     void setMaxPDUSize( int maxPDUSize );
-    
-    
+
+
     /**
      * Get an Interceptor instance from its name
-     * @param interceptorName The interceptor's name for which we want the instance 
+     * @param interceptorName The interceptor's name for which we want the instance
      * @return the interceptor for the given name
      */
     Interceptor getInterceptor( String interceptorName );
-    
-    
+
+
     /**
      * Get a new CSN
      * @return The CSN generated for this directory service
@@ -541,7 +537,7 @@ public interface DirectoryService extend
      * @param schemaManager The SchemaManager to associate
      */
     void setSchemaManager( SchemaManager schemaManager );
-    
+
 
     /**
      * the highest committed CSN value
@@ -550,31 +546,31 @@ public interface DirectoryService extend
      */
     void setContextCsn( String lastCommittedCsnVal );
 
-    
+
     /**
      * @return the current highest committed CSN value
      */
     String getContextCsn();
-    
-    
+
+
     /**
      * the time interval at which the DirectoryService's data is flushed to disk
      * 
      * @param syncPeriodMillis the syncPeriodMillis to set
      */
     void setSyncPeriodMillis( long syncPeriodMillis );
-    
-    
+
+
     /**
      * @return the syncPeriodMillis
      */
     long getSyncPeriodMillis();
-    
+
     /**
      * @return the cache service
      */
     CacheService getCacheService();
-    
+
 
     /**
      * @return The AccessControl AdministrativePoint cache
@@ -598,8 +594,8 @@ public interface DirectoryService extend
      * @return The TriggerExecution AdministrativePoint cache
      */
     DnNode<TriggerExecutionAdministrativePoint> getTriggerExecutionAPCache();
-    
-    
+
+
     /**
      * @return true if the password policy is enabled, false otherwise
      */

Modified: directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/LdapCoreSessionConnection.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/LdapCoreSessionConnection.java?rev=1201297&r1=1201296&r2=1201297&view=diff
==============================================================================
--- directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/LdapCoreSessionConnection.java (original)
+++ directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/LdapCoreSessionConnection.java Sat Nov 12 18:24:38 2011
@@ -934,7 +934,7 @@ public class LdapCoreSessionConnection i
             throw new IllegalArgumentException( "The entry Dn must not be null" );
         }
 
-        if ( entryDn.isRootDSE() )
+        if ( entryDn.isRootDse() )
         {
             throw new IllegalArgumentException( "The RootDSE cannot be moved" );
         }
@@ -944,7 +944,7 @@ public class LdapCoreSessionConnection i
             throw new IllegalArgumentException( "The new Dn must not be null" );
         }
 
-        if ( newDn.isRootDSE() )
+        if ( newDn.isRootDse() )
         {
             throw new IllegalArgumentException( "The RootDSE cannot be the target" );
         }

Modified: directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/OperationEnum.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/OperationEnum.java?rev=1201297&r1=1201296&r2=1201297&view=diff
==============================================================================
--- directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/OperationEnum.java (original)
+++ directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/OperationEnum.java Sat Nov 12 18:24:38 2011
@@ -6,16 +6,16 @@
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
- *  
+ * 
  *    http://www.apache.org/licenses/LICENSE-2.0
- *  
+ * 
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
  *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  *  KIND, either express or implied.  See the License for the
  *  specific language governing permissions and limitations
- *  under the License. 
- *  
+ *  under the License.
+ * 
  */
 package org.apache.directory.server.core.api;
 
@@ -25,67 +25,67 @@ package org.apache.directory.server.core
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
 public enum OperationEnum {
-	ADD( "add" ),
-	BIND( "bind" ),
-	COMPARE( "compare" ),
-	DELETE( "delete" ),
-	GET_ROOT_DSE( "getRootDSE" ),
-	HAS_ENTRY( "hasEntry" ),
-	LIST( "list" ),
-	LOOKUP( "lookup" ),
-	MODIFY( "modify" ),
-	MOVE( "move" ),
-	MOVE_AND_RENAME( "moveAndRename" ),
-	RENAME( "rename" ),
-	SEARCH( "search" ),
-	UNBIND( "unbind" );
-	
-	/** The associated method name */
-	private String methodName;
-	
-	/** A list of all the operations */
-	private static OperationEnum[] operations = new OperationEnum[] 
-			{
-				ADD,
-				BIND,
-				COMPARE,
-				DELETE,
-				GET_ROOT_DSE,
-				HAS_ENTRY,
-				LIST,
-				LOOKUP,
-				MODIFY,
-				MOVE,
-				MOVE_AND_RENAME,
-				RENAME,
-				SEARCH,
-				UNBIND
-			};
-	
-	/**
-	 * The private constructor 
-	 * @param methodName The associated method name
-	 */
-	private OperationEnum( String methodName )
-	{
-		this.methodName = methodName;
-	}
-	
-	
-	/**
-	 * @return The associated method name
-	 */
-	public String getMethodName()
-	{
-		return methodName;
-	}
-	
-	
-	/**
-	 * @return The list of all the operations
-	 */
-	public static OperationEnum[] getOperations()
-	{
-		return operations;
-	}
+    ADD( "add" ),
+    BIND( "bind" ),
+    COMPARE( "compare" ),
+    DELETE( "delete" ),
+    GET_ROOT_DSE( "getRootDse" ),
+    HAS_ENTRY( "hasEntry" ),
+    LIST( "list" ),
+    LOOKUP( "lookup" ),
+    MODIFY( "modify" ),
+    MOVE( "move" ),
+    MOVE_AND_RENAME( "moveAndRename" ),
+    RENAME( "rename" ),
+    SEARCH( "search" ),
+    UNBIND( "unbind" );
+    
+    /** The associated method name */
+    private String methodName;
+    
+    /** A list of all the operations */
+    private static OperationEnum[] operations = new OperationEnum[]
+            {
+                ADD,
+                BIND,
+                COMPARE,
+                DELETE,
+                GET_ROOT_DSE,
+                HAS_ENTRY,
+                LIST,
+                LOOKUP,
+                MODIFY,
+                MOVE,
+                MOVE_AND_RENAME,
+                RENAME,
+                SEARCH,
+                UNBIND
+            };
+    
+    /**
+     * The private constructor
+     * @param methodName The associated method name
+     */
+    private OperationEnum( String methodName )
+    {
+        this.methodName = methodName;
+    }
+    
+    
+    /**
+     * @return The associated method name
+     */
+    public String getMethodName()
+    {
+        return methodName;
+    }
+    
+    
+    /**
+     * @return The list of all the operations
+     */
+    public static OperationEnum[] getOperations()
+    {
+        return operations;
+    }
 }

Modified: directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/OperationManager.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/OperationManager.java?rev=1201297&r1=1201296&r2=1201297&view=diff
==============================================================================
--- directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/OperationManager.java (original)
+++ directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/OperationManager.java Sat Nov 12 18:24:38 2011
@@ -25,8 +25,8 @@ import org.apache.directory.server.core.
 import org.apache.directory.server.core.api.interceptor.context.BindOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.CompareOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.DeleteOperationContext;
-import org.apache.directory.server.core.api.interceptor.context.EntryOperationContext;
-import org.apache.directory.server.core.api.interceptor.context.GetRootDSEOperationContext;
+import org.apache.directory.server.core.api.interceptor.context.HasEntryOperationContext;
+import org.apache.directory.server.core.api.interceptor.context.GetRootDseOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.ListOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.LookupOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.ModifyOperationContext;
@@ -40,7 +40,7 @@ import org.apache.directory.shared.ldap.
 
 
 /**
- * An interface used by the DirectoryService to isolate operations that can be 
+ * An interface used by the DirectoryService to isolate operations that can be
  * performed on it.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
@@ -57,13 +57,13 @@ public interface OperationManager
     
     
     /**
-     * Get the RooDSE entry.
+     * Get the RooDse entry.
      * 
-     * @param getRootDseContext The getRootDSE() context
-     * @return The rootDSE if found
-     * @throws LdapException If we can't get back the rootDSE entry
+     * @param getRootDseContext The getRootDse() context
+     * @return The rootDse if found
+     * @throws LdapException If we can't get back the rootDse entry
      */
-    Entry getRootDSE( GetRootDSEOperationContext  getRootDseContext ) throws LdapException;
+    Entry getRootDse( GetRootDseOperationContext  getRootDseContext ) throws LdapException;
 
 
     /**
@@ -105,7 +105,7 @@ public interface OperationManager
     /**
      * TODO document after determining if this method should be here.
      */
-    boolean hasEntry( EntryOperationContext hasEntryContext ) throws LdapException;
+    boolean hasEntry( HasEntryOperationContext hasEntryContext ) throws LdapException;
 
 
     /**

Modified: directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/BaseInterceptor.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/BaseInterceptor.java?rev=1201297&r1=1201296&r2=1201297&view=diff
==============================================================================
--- directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/BaseInterceptor.java (original)
+++ directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/BaseInterceptor.java Sat Nov 12 18:24:38 2011
@@ -24,14 +24,15 @@ import java.util.HashSet;
 import java.util.Set;
 
 import org.apache.directory.server.core.api.DirectoryService;
+import org.apache.directory.server.core.api.InterceptorEnum;
 import org.apache.directory.server.core.api.LdapPrincipal;
 import org.apache.directory.server.core.api.filtering.EntryFilteringCursor;
 import org.apache.directory.server.core.api.interceptor.context.AddOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.BindOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.CompareOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.DeleteOperationContext;
-import org.apache.directory.server.core.api.interceptor.context.EntryOperationContext;
-import org.apache.directory.server.core.api.interceptor.context.GetRootDSEOperationContext;
+import org.apache.directory.server.core.api.interceptor.context.HasEntryOperationContext;
+import org.apache.directory.server.core.api.interceptor.context.GetRootDseOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.ListOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.LookupOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.ModifyOperationContext;
@@ -145,7 +146,7 @@ public abstract class BaseInterceptor im
         /**
          * {@inheritDoc}
          */
-        public void add( NextInterceptor next, AddOperationContext addContext ) throws LdapException
+        public void add( AddOperationContext addContext ) throws LdapException
         {
             nexus.add( addContext );
         }
@@ -181,16 +182,16 @@ public abstract class BaseInterceptor im
         /**
          * {@inheritDoc}
          */
-        public Entry getRootDSE( GetRootDSEOperationContext getRootDseContext ) throws LdapException
+        public Entry getRootDse( GetRootDseOperationContext getRootDseContext ) throws LdapException
         {
-            return nexus.getRootDSE( getRootDseContext );
+            return nexus.getRootDse( getRootDseContext );
         }
 
 
         /**
          * {@inheritDoc}
          */
-        public boolean hasEntry( EntryOperationContext hasEntryContext ) throws LdapException
+        public boolean hasEntry( HasEntryOperationContext hasEntryContext ) throws LdapException
         {
             return nexus.hasEntry( hasEntryContext );
         }
@@ -217,7 +218,7 @@ public abstract class BaseInterceptor im
         /**
          * {@inheritDoc}
          */
-        public void modify( NextInterceptor next, ModifyOperationContext modifyContext ) throws LdapException
+        public void modify( ModifyOperationContext modifyContext ) throws LdapException
         {
             nexus.modify( modifyContext );
         }
@@ -226,7 +227,7 @@ public abstract class BaseInterceptor im
         /**
          * {@inheritDoc}
          */
-        public void move( NextInterceptor next, MoveOperationContext moveContext ) throws LdapException
+        public void move( MoveOperationContext moveContext ) throws LdapException
         {
             nexus.move( moveContext );
         }
@@ -235,7 +236,7 @@ public abstract class BaseInterceptor im
         /**
          * {@inheritDoc}
          */
-        public void moveAndRename( NextInterceptor next, MoveAndRenameOperationContext moveAndRenameContext ) throws LdapException
+        public void moveAndRename( MoveAndRenameOperationContext moveAndRenameContext ) throws LdapException
         {
             nexus.moveAndRename( moveAndRenameContext );
         }
@@ -244,7 +245,7 @@ public abstract class BaseInterceptor im
         /**
          * {@inheritDoc}
          */
-        public void rename( NextInterceptor next, RenameOperationContext renameContext ) throws LdapException
+        public void rename( RenameOperationContext renameContext ) throws LdapException
         {
             nexus.rename( renameContext );
         }
@@ -253,7 +254,7 @@ public abstract class BaseInterceptor im
         /**
          * {@inheritDoc}
          */
-        public EntryFilteringCursor search( NextInterceptor next, SearchOperationContext searchContext ) throws LdapException
+        public EntryFilteringCursor search( SearchOperationContext searchContext ) throws LdapException
         {
             return nexus.search( searchContext );
         }
@@ -293,7 +294,7 @@ public abstract class BaseInterceptor im
 
 
     /**
-     * Creates a new instance.
+     * Creates a new instance with a default name : the class name itself.
      */
     protected BaseInterceptor()
     {
@@ -302,7 +303,9 @@ public abstract class BaseInterceptor im
 
 
     /**
-     * Creates a new instance.
+     * Creates a new instance with a given name.
+     * 
+     * @param name the Interceptor name
      */
     protected BaseInterceptor( String name )
     {
@@ -311,6 +314,17 @@ public abstract class BaseInterceptor im
 
 
     /**
+     * Creates a new instance with a given name.
+     * 
+     * @param name the Interceptor name
+     */
+    protected BaseInterceptor( InterceptorEnum interceptor )
+    {
+        this.name = interceptor.getName();
+    }
+
+
+    /**
      * This method does nothing by default.
      * @throws Exception
      */
@@ -378,9 +392,23 @@ public abstract class BaseInterceptor im
     /**
      * {@inheritDoc}
      */
-    public void add( NextInterceptor next, AddOperationContext addContext ) throws LdapException
+    public void add( AddOperationContext addContext ) throws LdapException
+    {
+        // Do nothing
+    }
+
+
+    /**
+     * Calls the next interceptor for the add operation.
+     * 
+     * @param addContext The context in which we are executing this operation
+     * @throws LdapException If something went wrong
+     */
+    protected final void next( AddOperationContext addContext ) throws LdapException
     {
-        next.add( addContext );
+        Interceptor interceptor = getNextInterceptor( addContext );
+
+        interceptor.add( addContext );
     }
 
 
@@ -455,7 +483,7 @@ public abstract class BaseInterceptor im
     /**
      * {@inheritDoc}
      */
-    public Entry getRootDSE( GetRootDSEOperationContext getRootDseContext ) throws LdapException
+    public Entry getRootDse( GetRootDseOperationContext getRootDseContext ) throws LdapException
     {
         // Nothing to do
         return null;
@@ -469,18 +497,18 @@ public abstract class BaseInterceptor im
      * @return the rootDSE
      * @throws LdapException If something went wrong
      */
-    protected final Entry next( GetRootDSEOperationContext getRootDseContext ) throws LdapException
+    protected final Entry next( GetRootDseOperationContext getRootDseContext ) throws LdapException
     {
         Interceptor interceptor = getNextInterceptor( getRootDseContext );
 
-        return interceptor.getRootDSE( getRootDseContext );
+        return interceptor.getRootDse( getRootDseContext );
     }
 
 
     /**
      * {@inheritDoc}
      */
-    public boolean hasEntry( EntryOperationContext hasEntryContext ) throws LdapException
+    public boolean hasEntry( HasEntryOperationContext hasEntryContext ) throws LdapException
     {
         // Return false in any case
         return false;
@@ -494,7 +522,7 @@ public abstract class BaseInterceptor im
      * @return a boolean indicating if the entry exists on the server
      * @throws LdapException If something went wrong
      */
-    protected final boolean next( EntryOperationContext hasEntryContext ) throws LdapException
+    protected final boolean next( HasEntryOperationContext hasEntryContext ) throws LdapException
     {
         Interceptor interceptor = getNextInterceptor( hasEntryContext );
 
@@ -550,36 +578,116 @@ public abstract class BaseInterceptor im
     }
 
 
-    public void modify( NextInterceptor next, ModifyOperationContext modifyContext ) throws LdapException
+    /**
+     * {@inheritDoc}
+     */
+    public void modify( ModifyOperationContext modifyContext ) throws LdapException
     {
-        next.modify( modifyContext );
+        // Nothing to do
+    }
+
+
+    /**
+     * Calls the next interceptor for the modify operation.
+     * 
+     * @param modifyContext The context in which we are executing this operation
+     * @throws LdapException If something went wrong
+     */
+    protected final void next( ModifyOperationContext modifyContext ) throws LdapException
+    {
+        Interceptor interceptor = getNextInterceptor( modifyContext );
+
+        interceptor.modify( modifyContext );
     }
 
 
     /**
      * {@inheritDoc}
      */
-    public void move( NextInterceptor next, MoveOperationContext moveContext ) throws LdapException
+    public void move( MoveOperationContext moveContext ) throws LdapException
     {
-        next.move( moveContext );
+        // Do nothing
     }
 
 
-    public void moveAndRename( NextInterceptor next, MoveAndRenameOperationContext moveAndRenameContext ) throws LdapException
+    /**
+     * Calls the next interceptor for the move operation.
+     * 
+     * @param moveContext The context in which we are executing this operation
+     * @throws LdapException If something went wrong
+     */
+    protected final void next( MoveOperationContext moveContext ) throws LdapException
     {
-        next.moveAndRename( moveAndRenameContext );
+        Interceptor interceptor = getNextInterceptor( moveContext );
+
+        interceptor.move( moveContext );
     }
 
 
-    public void rename( NextInterceptor next, RenameOperationContext renameContext ) throws LdapException
+    public void moveAndRename( MoveAndRenameOperationContext moveAndRenameContext ) throws LdapException
     {
-        next.rename( renameContext );
+        // Do nothing
     }
 
 
-    public EntryFilteringCursor search( NextInterceptor next, SearchOperationContext searchContext ) throws LdapException
+    /**
+     * Calls the next interceptor for the moveAndRename operation.
+     * 
+     * @param moveAndRenameContext The context in which we are executing this operation
+     * @throws LdapException If something went wrong
+     */
+    protected final void next( MoveAndRenameOperationContext moveAndRenameContext ) throws LdapException
+    {
+        Interceptor interceptor = getNextInterceptor( moveAndRenameContext );
+
+        interceptor.moveAndRename( moveAndRenameContext );
+    }
+
+
+    /**
+     * {@inheritDoc}
+     */
+    public void rename( RenameOperationContext renameContext ) throws LdapException
+    {
+        // Nothing to do
+    }
+
+
+    /**
+     * Calls the next interceptor for the rename operation.
+     * 
+     * @param renameContext The context in which we are executing this operation
+     * @throws LdapException If something went wrong
+     */
+    protected final void next( RenameOperationContext renameContext ) throws LdapException
+    {
+        Interceptor interceptor = getNextInterceptor( renameContext );
+
+        interceptor.rename( renameContext );
+    }
+
+
+    /**
+     * {@inheritDoc}
+     */
+    public EntryFilteringCursor search( SearchOperationContext searchContext ) throws LdapException
     {
-        return next.search( searchContext );
+        return null;
+    }
+
+
+    /**
+     * Calls the next interceptor for the search operation.
+     * 
+     * @param searchContext The context in which we are executing this operation
+     * @return the cursor containing the found entries
+     * @throws LdapException If something went wrong
+     */
+    protected final EntryFilteringCursor next( SearchOperationContext searchContext ) throws LdapException
+    {
+        Interceptor interceptor = getNextInterceptor( searchContext );
+
+        return interceptor.search( searchContext );
     }
 
 

Modified: directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/Interceptor.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/Interceptor.java?rev=1201297&r1=1201296&r2=1201297&view=diff
==============================================================================
--- directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/AbstractOperationContext.java (original)
+++ directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/AbstractOperationContext.java Sat Nov 12 18:24:38 2011
@@ -6,16 +6,16 @@
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
- *  
+ * 
  *    http://www.apache.org/licenses/LICENSE-2.0
- *  
+ * 
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
  *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  *  KIND, either express or implied.  See the License for the
  *  specific language governing permissions and limitations
- *  under the License. 
- *  
+ *  under the License.
+ * 
  */
 package org.apache.directory.server.core.api.interceptor.context;
 
@@ -49,13 +49,13 @@ public abstract class AbstractOperationC
 
     /** The Dn associated with the context */
     protected Dn dn;
-    
+
     /** The entry associated with the target entry of this OperationContext */
     protected Entry entry;
 
     /** The original Entry */
     protected Entry originalEntry;
-    
+
     /** The associated request's controls */
     protected Map<String, Control> requestControls = new HashMap<String, Control>(4);
 
@@ -64,26 +64,26 @@ public abstract class AbstractOperationC
 
     /** the Interceptors bypassed by this operation */
     protected Collection<String> byPassed;
-    
+
     /** The interceptors to call for this operation */
     protected List<String> interceptors;
-    
+
     /** The current interceptor position */
     protected int currentInterceptor;
-    
-	protected LdapPrincipal authorizedPrincipal;
-    
+
+    protected LdapPrincipal authorizedPrincipal;
+
     /** The core session */
     protected CoreSession session;
-    
+
     protected OperationContext next;
-    
+
     protected OperationContext previous;
 
     /** A flag used to tell if we should consider referrals as standard entries */
     protected boolean throwReferral;
-    
-    
+
+
     /**
      * Creates a new instance of AbstractOperationContext.
      */
@@ -92,8 +92,8 @@ public abstract class AbstractOperationC
         this.session = session;
         currentInterceptor = 0;
     }
-    
-    
+
+
     /**
      * Creates a new instance of AbstractOperationContext.
      *
@@ -103,8 +103,8 @@ public abstract class AbstractOperationC
     {
         this.dn = dn;
         this.session = session;
-        
-        // The flag is set to ignore, so that the revert operation can act on 
+
+        // The flag is set to ignore, so that the revert operation can act on
         // the entries, even if they are referrals.
         ignoreReferral();
     }
@@ -114,14 +114,14 @@ public abstract class AbstractOperationC
     {
         return session;
     }
-    
-    
+
+
     public void setSession( CoreSession session )
     {
         this.session = session;
     }
-    
-    
+
+
     protected void setAuthorizedPrincipal( LdapPrincipal authorizedPrincipal )
     {
         this.authorizedPrincipal = authorizedPrincipal;
@@ -136,7 +136,7 @@ public abstract class AbstractOperationC
         return dn;
     }
 
-    
+
     /**
      * Set the context Dn
      *
@@ -147,25 +147,25 @@ public abstract class AbstractOperationC
         this.dn = dn;
     }
 
-    
+
     public void addRequestControl( Control requestControl )
     {
         requestControls.put( requestControl.getOid(), requestControl );
     }
 
-    
+
     public Control getRequestControl( String numericOid )
     {
         return requestControls.get( numericOid );
     }
 
-    
+
     public boolean hasRequestControl( String numericOid )
     {
         return requestControls.containsKey( numericOid );
     }
 
-    
+
     public boolean hasRequestControls()
     {
         return ! requestControls.isEmpty();
@@ -196,7 +196,7 @@ public abstract class AbstractOperationC
         {
             return EMPTY_CONTROLS;
         }
-        
+
         return responseControls.values().toArray( EMPTY_CONTROLS );
     }
 
@@ -221,13 +221,13 @@ public abstract class AbstractOperationC
         }
     }
 
-    
+
     public void setRequestControls( Map<String, Control> requestControls )
     {
         this.requestControls = requestControls;
     }
 
-    
+
     /**
      * @return the operation name
      */
@@ -263,35 +263,35 @@ public abstract class AbstractOperationC
         {
             return Collections.emptyList();
         }
-        
+
         return Collections.unmodifiableCollection( byPassed );
     }
-    
-    
+
+
     /**
      * {@inheritDoc}
      */
     public final void setInterceptors( List<String> interceptors )
     {
-    	this.interceptors = interceptors;
+        this.interceptors = interceptors;
     }
-    
-    
+
+
     /**
      * {@inheritDoc}
      */
-    public final String getNextInterceptor() 
+    public final String getNextInterceptor()
     {
-    	if ( currentInterceptor == interceptors.size() )
-    	{
-    		return "FINAL";
-    	}
-    	
-		String interceptor = interceptors.get( currentInterceptor );
-		currentInterceptor++;
-		
-		return interceptor;
-	}
+        if ( currentInterceptor == interceptors.size() )
+        {
+            return "FINAL";
+        }
+
+        String interceptor = interceptors.get( currentInterceptor );
+        currentInterceptor++;
+
+        return interceptor;
+    }
 
 
     /**
@@ -304,7 +304,7 @@ public abstract class AbstractOperationC
         this.byPassed = byPassed;
     }
 
-    
+
     /**
      * Checks to see if an Interceptor is bypassed for this operation.
      *
@@ -327,15 +327,15 @@ public abstract class AbstractOperationC
         return byPassed != null && !byPassed.isEmpty();
     }
 
-    
+
     private void setup( AbstractOperationContext opContext )
     {
         opContext.setPreviousOperation( this );
         next = opContext;
         opContext.setAuthorizedPrincipal( authorizedPrincipal );
     }
-    
-    
+
+
     /**
      * {@inheritDoc}
      */
@@ -346,8 +346,8 @@ public abstract class AbstractOperationC
         addContext.setByPassed( byPassed );
         session.getDirectoryService().getOperationManager().add( addContext );
     }
-    
-    
+
+
     /**
      * {@inheritDoc}
      */
@@ -357,17 +357,17 @@ public abstract class AbstractOperationC
         setup( deleteContext );
         session.getDirectoryService().getOperationManager().delete( deleteContext );
     }
-    
-    
+
+
     /**
      * {@inheritDoc}
      */
     public boolean hasEntry( Dn dn, Collection<String> byPassed ) throws LdapException
     {
-        EntryOperationContext hasEntryContext = new EntryOperationContext( session, dn );
+        HasEntryOperationContext hasEntryContext = new HasEntryOperationContext( session, dn );
         setup( hasEntryContext );
         hasEntryContext.setInterceptors( session.getDirectoryService().getInterceptors( OperationEnum.HAS_ENTRY ) );
-        
+
         return session.getDirectoryService().getOperationManager().hasEntry( hasEntryContext );
     }
 
@@ -378,7 +378,7 @@ public abstract class AbstractOperationC
         {
             throw new IllegalStateException( I18n.err( I18n.ERR_319 ) );
         }
-        
+
         return session.getDirectoryService().getOperationManager().lookup( lookupContext );
     }
 
@@ -398,8 +398,8 @@ public abstract class AbstractOperationC
         lookupContext.setAttrsId( attrIds );
         return session.getDirectoryService().getOperationManager().lookup( lookupContext );
     }
-    
-    
+
+
     public void modify( Dn dn, List<Modification> mods, Collection<String> byPassed ) throws LdapException
     {
         ModifyOperationContext modifyContext = new ModifyOperationContext( session, dn, mods );
@@ -407,8 +407,8 @@ public abstract class AbstractOperationC
         modifyContext.setByPassed( byPassed );
         session.getDirectoryService().getOperationManager().modify( modifyContext );
     }
-    
-    
+
+
     // TODO - need synchronization here and where we update links
     public LookupOperationContext newLookupContext( Dn dn )
     {
@@ -422,62 +422,62 @@ public abstract class AbstractOperationC
         {
             return authorizedPrincipal;
         }
-        
+
         return session.getEffectivePrincipal();
     }
-    
-    
+
+
     // -----------------------------------------------------------------------
     // OperationContext Linked List Methods
     // -----------------------------------------------------------------------
-    
-    
+
+
     public boolean isFirstOperation()
     {
         return previous == null;
     }
-    
-    
+
+
     public OperationContext getFirstOperation()
     {
         if ( previous == null )
         {
             return this;
         }
-        
+
         return previous.getFirstOperation();
     }
-    
-    
+
+
     public OperationContext getLastOperation()
     {
         if ( next == null )
         {
             return this;
         }
-        
+
         return next.getLastOperation();
     }
-    
-    
+
+
     public OperationContext getNextOperation()
     {
         return next;
     }
-    
-    
+
+
     protected void setNextOperation( OperationContext next )
     {
         this.next = next;
     }
-    
-    
+
+
     public OperationContext getPreviousOperation()
     {
         return previous;
     }
-    
-    
+
+
     protected void setPreviousOperation( OperationContext previous )
     {
         this.previous = previous;
@@ -500,8 +500,8 @@ public abstract class AbstractOperationC
     {
         return entry;
     }
-    
-    
+
+
     /**
      * Set the throwReferral flag to true
      */
@@ -509,8 +509,8 @@ public abstract class AbstractOperationC
     {
         throwReferral = true;
     }
-    
-    
+
+
     /**
      * @return <code>true</code> if the referrals are thrown
      */

Modified: directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/AddOperationContext.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/AddOperationContext.java?rev=1201297&r1=1201296&r2=1201297&view=diff
==============================================================================
--- directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/AddOperationContext.java (original)
+++ directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/AddOperationContext.java Sat Nov 12 18:24:38 2011
@@ -6,21 +6,22 @@
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
- *  
+ * 
  *    http://www.apache.org/licenses/LICENSE-2.0
- *  
+ * 
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
  *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  *  KIND, either express or implied.  See the License for the
  *  specific language governing permissions and limitations
- *  under the License. 
- *  
+ *  under the License.
+ * 
  */
 package org.apache.directory.server.core.api.interceptor.context;
 
 
 import org.apache.directory.server.core.api.CoreSession;
+import org.apache.directory.server.core.api.OperationEnum;
 import org.apache.directory.server.core.api.entry.ClonedServerEntry;
 import org.apache.directory.shared.ldap.model.message.controls.ManageDsaIT;
 import org.apache.directory.shared.ldap.model.entry.DefaultEntry;
@@ -42,49 +43,69 @@ public class AddOperationContext extends
     /**
      * Creates a new instance of AddOperationContext.
      * 
-     * @param session the current Session 
+     * @param session the current Session
      */
     public AddOperationContext( CoreSession session )
     {
         super( session );
+
+        if ( session != null )
+        {
+            setInterceptors( session.getDirectoryService().getInterceptors( OperationEnum.ADD ) );
+        }
     }
 
 
     /**
      * Creates a new instance of AddOperationContext.
      * 
-     * @param session the current Session 
+     * @param session the current Session
      * @param dn the name of the entry being added
      */
     public AddOperationContext( CoreSession session, Dn dn )
     {
         super( session, dn );
+
+        if ( session != null )
+        {
+            setInterceptors( session.getDirectoryService().getInterceptors( OperationEnum.ADD ) );
+        }
     }
 
 
     /**
      * Creates a new instance of AddOperationContext.
      * 
-     * @param session the current Session 
+     * @param session the current Session
      * @param entry the entry being added
      */
     public AddOperationContext( CoreSession session, Entry entry )
     {
         super( session, entry.getDn() );
         this.entry = new ClonedServerEntry( entry );
+        if ( session != null )
+        {
+            setInterceptors( session.getDirectoryService().getInterceptors( OperationEnum.ADD ) );
+        }
     }
 
 
     /**
      * Creates a new instance of ModifyOperationContext.
      *
-     * @param session the current Session 
+     * @param session the current Session
      * @param dn the name of the entry being added
      * @param entry the entry being added
      */
     public AddOperationContext( CoreSession session, Dn dn, Entry entry )
     {
         super( session, dn );
+
+        if ( session != null )
+        {
+            setInterceptors( session.getDirectoryService().getInterceptors( OperationEnum.ADD ) );
+        }
+
         this.entry = new ClonedServerEntry( entry );
     }
 
@@ -92,11 +113,17 @@ public class AddOperationContext extends
     public AddOperationContext( CoreSession session, AddRequest addRequest ) throws LdapException
     {
         super( session );
-        entry = new ClonedServerEntry( 
+
+        if ( session != null )
+        {
+            setInterceptors( session.getDirectoryService().getInterceptors( OperationEnum.ADD ) );
+        }
+
+        entry = new ClonedServerEntry(
             new DefaultEntry( session.getDirectoryService().getSchemaManager(), addRequest.getEntry() ) );
         dn = addRequest.getEntry().getDn();
         requestControls = addRequest.getControls();
-        
+
         if ( requestControls.containsKey( ManageDsaIT.OID ) )
         {
             ignoreReferral();
@@ -116,7 +143,7 @@ public class AddOperationContext extends
         return MessageTypeEnum.ADD_REQUEST.name();
     }
 
-    
+
     /**
      * @see Object#toString()
      */

Modified: directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/ModifyOperationContext.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/ModifyOperationContext.java?rev=1201297&r1=1201296&r2=1201297&view=diff
==============================================================================
--- directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/ModifyOperationContext.java (original)
+++ directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/ModifyOperationContext.java Sat Nov 12 18:24:38 2011
@@ -6,16 +6,16 @@
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
- *  
+ * 
  *    http://www.apache.org/licenses/LICENSE-2.0
- *  
+ * 
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
  *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  *  KIND, either express or implied.  See the License for the
  *  specific language governing permissions and limitations
- *  under the License. 
- *  
+ *  under the License.
+ * 
  */
 package org.apache.directory.server.core.api.interceptor.context;
 
@@ -24,6 +24,7 @@ import java.util.ArrayList;
 import java.util.List;
 
 import org.apache.directory.server.core.api.CoreSession;
+import org.apache.directory.server.core.api.OperationEnum;
 import org.apache.directory.server.core.api.entry.ServerEntryUtils;
 import org.apache.directory.shared.ldap.model.message.controls.ManageDsaIT;
 import org.apache.directory.shared.ldap.model.entry.DefaultModification;
@@ -60,6 +61,11 @@ public class ModifyOperationContext exte
     public ModifyOperationContext( CoreSession session )
     {
         super( session );
+
+        if ( session != null )
+        {
+            setInterceptors( session.getDirectoryService().getInterceptors( OperationEnum.MODIFY ) );
+        }
     }
 
 
@@ -73,6 +79,11 @@ public class ModifyOperationContext exte
     {
         super( session, dn );
 
+        if ( session != null )
+        {
+            setInterceptors( session.getDirectoryService().getInterceptors( OperationEnum.MODIFY ) );
+        }
+
         this.modItems = modItems;
     }
 
@@ -81,6 +92,11 @@ public class ModifyOperationContext exte
     {
         super( session, modifyRequest.getName() );
 
+        if ( session != null )
+        {
+            setInterceptors( session.getDirectoryService().getInterceptors( OperationEnum.MODIFY ) );
+        }
+
         modItems = ServerEntryUtils.toServerModification( modifyRequest.getModifications().toArray(
             new DefaultModification[0] ), session.getDirectoryService().getSchemaManager() );
 
@@ -118,7 +134,7 @@ public class ModifyOperationContext exte
 
     public static List<Modification> createModItems( Entry serverEntry, ModificationOperation modOp )
         throws LdapException
-    {
+        {
         List<Modification> items = new ArrayList<Modification>( serverEntry.size() );
 
         for ( Attribute attribute : serverEntry )
@@ -127,7 +143,7 @@ public class ModifyOperationContext exte
         }
 
         return items;
-    }
+        }
 
 
     /**
@@ -140,7 +156,7 @@ public class ModifyOperationContext exte
 
 
     /**
-     * Returns the entry after it has been renamed and potentially changed for 
+     * Returns the entry after it has been renamed and potentially changed for
      * Rdn alterations.
      *
      * @return the new renamed entry

Modified: directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/MoveAndRenameOperationContext.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/MoveAndRenameOperationContext.java?rev=1201297&r1=1201296&r2=1201297&view=diff
==============================================================================
--- directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/MoveAndRenameOperationContext.java (original)
+++ directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/MoveAndRenameOperationContext.java Sat Nov 12 18:24:38 2011
@@ -21,6 +21,7 @@ package org.apache.directory.server.core
 
 
 import org.apache.directory.server.core.api.CoreSession;
+import org.apache.directory.server.core.api.OperationEnum;
 import org.apache.directory.server.i18n.I18n;
 import org.apache.directory.shared.ldap.model.exception.LdapInvalidDnException;
 import org.apache.directory.shared.ldap.model.message.ModifyDnRequest;
@@ -46,6 +47,7 @@ public class MoveAndRenameOperationConte
     public MoveAndRenameOperationContext( CoreSession session )
     {
         super( session );
+        setInterceptors( session.getDirectoryService().getInterceptors( OperationEnum.MOVE_AND_RENAME ) );
     }
 
 
@@ -61,7 +63,8 @@ public class MoveAndRenameOperationConte
     {
         super( session, oldDn, newRdn, delOldRdn );
         this.newSuperiorDn = newSuperiorDn;
-        
+        setInterceptors( session.getDirectoryService().getInterceptors( OperationEnum.MOVE_AND_RENAME ) );
+
         try
         {
             newDn = newSuperiorDn.add( newRdn );
@@ -78,6 +81,7 @@ public class MoveAndRenameOperationConte
         // super sets the newRdn and the delOldRdn members and tests
         super( session, modifyDnRequest );
         this.newSuperiorDn = modifyDnRequest.getNewSuperior();
+        setInterceptors( session.getDirectoryService().getInterceptors( OperationEnum.MOVE_AND_RENAME ) );
 
         if ( newSuperiorDn == null )
         {

Modified: directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/MoveOperationContext.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/MoveOperationContext.java?rev=1201297&r1=1201296&r2=1201297&view=diff
==============================================================================
--- directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/MoveOperationContext.java (original)
+++ directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/MoveOperationContext.java Sat Nov 12 18:24:38 2011
@@ -6,21 +6,22 @@
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
- *  
+ * 
  *    http://www.apache.org/licenses/LICENSE-2.0
- *  
+ * 
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
  *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  *  KIND, either express or implied.  See the License for the
  *  specific language governing permissions and limitations
- *  under the License. 
- *  
+ *  under the License.
+ * 
  */
 package org.apache.directory.server.core.api.interceptor.context;
 
 
 import org.apache.directory.server.core.api.CoreSession;
+import org.apache.directory.server.core.api.OperationEnum;
 import org.apache.directory.server.i18n.I18n;
 import org.apache.directory.shared.ldap.model.exception.LdapInvalidDnException;
 import org.apache.directory.shared.ldap.model.message.MessageTypeEnum;
@@ -43,13 +44,13 @@ public class MoveOperationContext extend
 
     /** The entry Rdn */
     private Rdn rdn;
-    
+
     /** The newSuperior Dn */
     private Dn newSuperior;
-    
+
     /** The New target Dn */
     private Dn newDn;
-    
+
 
     /**
      * Creates a new instance of MoveOperationContext.
@@ -57,8 +58,9 @@ public class MoveOperationContext extend
     public MoveOperationContext( CoreSession session )
     {
         super( session );
+        setInterceptors( session.getDirectoryService().getInterceptors( OperationEnum.MOVE ) );
     }
-    
+
 
     /**
      * Creates a new instance of MoveOperationContext.
@@ -68,8 +70,9 @@ public class MoveOperationContext extend
         super( session, oldDn );
         this.newSuperior = newSuperior;
         oldSuperior = oldDn.getParent();
-        rdn = (Rdn)( oldDn.getRdn().clone() );
-        
+        rdn = ( oldDn.getRdn().clone() );
+        setInterceptors( session.getDirectoryService().getInterceptors( OperationEnum.MOVE ) );
+
         try
         {
             newDn = newSuperior.add( rdn );
@@ -80,24 +83,25 @@ public class MoveOperationContext extend
         }
     }
 
-    
+
     public MoveOperationContext( CoreSession session, ModifyDnRequest modifyDnRequest )
     {
         super( session, modifyDnRequest.getName() );
         this.newSuperior = modifyDnRequest.getNewSuperior();
-        
+        setInterceptors( session.getDirectoryService().getInterceptors( OperationEnum.MOVE ) );
+
         if ( newSuperior == null )
         {
             throw new IllegalArgumentException( I18n.err( I18n.ERR_326_NEW_SUPERIROR_CANNOT_BE_NULL, modifyDnRequest ) );
         }
-        
+
         this.requestControls = modifyDnRequest.getControls();
-        
+
         if ( modifyDnRequest.getNewRdn() != null )
         {
             throw new IllegalArgumentException( I18n.err( I18n.ERR_327_MOVE_AND_RENAME_OPERATION, modifyDnRequest ) );
         }
-        
+
         if ( requestControls.containsKey( ManageDsaIT.OID ) )
         {
             ignoreReferral();
@@ -108,10 +112,10 @@ public class MoveOperationContext extend
         }
 
         oldSuperior = modifyDnRequest.getName().getParent();
-        rdn = (Rdn)(modifyDnRequest.getName().getRdn().clone());
-        
+        rdn = (modifyDnRequest.getName().getRdn().clone());
+
         try
-        { 
+        {
             newDn = newSuperior.add( rdn );
         }
         catch ( LdapInvalidDnException lide )
@@ -137,7 +141,7 @@ public class MoveOperationContext extend
     {
         return newSuperior;
     }
-    
+
 
     /**
      *  @return The Rdn
@@ -146,8 +150,8 @@ public class MoveOperationContext extend
     {
         return rdn;
     }
-    
-    
+
+
     /**
      *  @return The new Dn
      */
@@ -155,7 +159,7 @@ public class MoveOperationContext extend
     {
         return newDn;
     }
-    
+
 
     /**
      * @return the operation name
@@ -165,13 +169,13 @@ public class MoveOperationContext extend
         return MessageTypeEnum.MODIFYDN_REQUEST.name();
     }
 
-    
+
     /**
      * @see Object#toString()
      */
     public String toString()
     {
         return "ReplaceContext for old Dn '" + getDn().getName() + "'" +
-        ", newSuperior '" + newSuperior + "'";
+            ", newSuperior '" + newSuperior + "'";
     }
 }
--- directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/Interceptor.java (original)
+++ directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/Interceptor.java Sat Nov 12 18:24:38 2011
@@ -26,8 +26,8 @@ import org.apache.directory.server.core.
 import org.apache.directory.server.core.api.interceptor.context.BindOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.CompareOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.DeleteOperationContext;
-import org.apache.directory.server.core.api.interceptor.context.EntryOperationContext;
-import org.apache.directory.server.core.api.interceptor.context.GetRootDSEOperationContext;
+import org.apache.directory.server.core.api.interceptor.context.HasEntryOperationContext;
+import org.apache.directory.server.core.api.interceptor.context.GetRootDseOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.ListOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.LookupOperationContext;
 import org.apache.directory.server.core.api.interceptor.context.ModifyOperationContext;
@@ -128,12 +128,11 @@ public interface Interceptor
 
     /**
      * Filters {@link Partition#add( AddOperationContext )} call.
-     * 
-     * @param next The next {@link Interceptor} in the chain
      * @param addContext The {@link AddOperationContext} instance
+     * 
      * @throws LdapException If we had some error while processing the Add operation
      */
-    void add( NextInterceptor next, AddOperationContext addContext ) throws LdapException;
+    void add( AddOperationContext addContext ) throws LdapException;
 
 
     /**
@@ -155,19 +154,19 @@ public interface Interceptor
 
 
     /**
-     * Filters {@link DefaultPartitionNexus#getRootDSE( GetRootDSEOperationContext )} call.
+     * Filters {@link DefaultPartitionNexus#getRootDse( GetRootDseOperationContext )} call.
      * 
      * @param getRootDseContext The getRoot() operation context
      * @return The RootDSE entry, if found
      * @throws LdapException If we can't get back the RootDSE entry
      */
-    Entry getRootDSE( GetRootDSEOperationContext getRootDseContext ) throws LdapException;
+    Entry getRootDse( GetRootDseOperationContext getRootDseContext ) throws LdapException;
 
 
     /**
      * Filters {@link Partition#hasEntry( EntryOperationContext )} call.
      */
-    boolean hasEntry( EntryOperationContext hasEntryContext ) throws LdapException;
+    boolean hasEntry( HasEntryOperationContext hasEntryContext ) throws LdapException;
 
 
     /**
@@ -185,31 +184,31 @@ public interface Interceptor
     /**
      * Filters {@link Partition#modify( ModifyOperationContext )} call.
      */
-    void modify( NextInterceptor next, ModifyOperationContext modifyContext ) throws LdapException;
+    void modify( ModifyOperationContext modifyContext ) throws LdapException;
 
 
     /**
      * Filters {@link Partition#move( MoveOperationContext )} call.
      */
-    void move( NextInterceptor next, MoveOperationContext moveContext ) throws LdapException;
+    void move( MoveOperationContext moveContext ) throws LdapException;
 
 
     /**
      * Filters {@link Partition#moveAndRename( MoveAndRenameOperationContext) } call.
      */
-    void moveAndRename( NextInterceptor next, MoveAndRenameOperationContext moveAndRenameContext ) throws LdapException;
+    void moveAndRename( MoveAndRenameOperationContext moveAndRenameContext ) throws LdapException;
 
 
     /**
      * Filters {@link Partition#rename( RenameOperationContext )} call.
      */
-    void rename( NextInterceptor next, RenameOperationContext renameContext ) throws LdapException;
+    void rename( RenameOperationContext renameContext ) throws LdapException;
 
 
     /**
      * Filters {@link Partition#search( SearchOperationContext )} call.
      */
-    EntryFilteringCursor search( NextInterceptor next, SearchOperationContext searchContext ) throws LdapException;
+    EntryFilteringCursor search( SearchOperationContext searchContext ) throws LdapException;
 
 
     /**
@@ -155,19 +154,19 @@ public interface Interceptor
 
     /**
-     * Filters {@link Partition#hasEntry( EntryOperationContext )} call.
+     * Filters {@link Partition#hasEntry( HasEntryOperationContext )} call.
      */

Modified: directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/AbstractOperationContext.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/apacheds-txns/core-api/src/main/java/org/apache/directory/server/core/api/interceptor/context/AbstractOperationContext.java?rev=1201297&r1=1201296&r2=1201297&view=diff
==============================================================================